@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2012 by Volker Lanz <vl@fidra.de>                      *
+ *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -24,6 +25,7 @@
 #include "fs/ext3.h"
 #include "fs/ext4.h"
 #include "fs/extended.h"
+#include "fs/f2fs.h"
 #include "fs/fat16.h"
 #include "fs/fat32.h"
 #include "fs/hfs.h"
@@ -61,6 +63,7 @@ void FileSystemFactory::init()
     m_FileSystems.insert(FileSystem::Ext3, new FS::ext3(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Ext4, new FS::ext4(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Extended, new FS::extended(-1, -1, -1, QString()));
+    m_FileSystems.insert(FileSystem::F2fs, new FS::f2fs(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Fat16, new FS::fat16(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Fat32, new FS::fat32(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Hfs, new FS::hfs(-1, -1, -1, QString()));
@@ -87,6 +90,7 @@ void FileSystemFactory::init()
     FS::ext3::init();
     FS::ext4::init();
     FS::extended::init();
+    FS::f2fs::init();
     FS::fat16::init();
     FS::fat32::init();
     FS::hfs::init();
@@ -129,6 +133,7 @@ FileSystem* FileSystemFactory::create(FileSystem::Type t, qint64 firstsector, qi
     case FileSystem::Ext3:         fs = new FS::ext3(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Ext4:         fs = new FS::ext4(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Extended:     fs = new FS::extended(firstsector, lastsector, sectorsused, label); break;
+    case FileSystem::F2fs:         fs = new FS::f2fs(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Fat16:        fs = new FS::fat16(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Fat32:        fs = new FS::fat32(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Hfs:          fs = new FS::hfs(firstsector, lastsector, sectorsused, label); break;
